crun 1 "User Commands"
==================================================

# NAME

crun - a fast and lightweight OCI runtime

# SYNOPSIS

crun [global options] command [command options] [arguments...]

# DESCRIPTION

crun is a command line program for running Linux containers that
follow the Open Container Initiative (OCI) format.

# COMMANDS

**create**
Create a container.  The runtime detaches from the container process
once the container environment is created.  It is necessary to
successively use `start` for starting the container.

**delete**
Remove definition for a container.

**exec**
Exec a command in a running container.

**list**
List known containers.

**kill**
Send the specified signal to the container init process.  If no signal
is specified, SIGTERM is used.

**run**
Create and immediately start a container.

**spec**
Generate a configuration file.

**start**
Start a container that was previously created.  A container cannot be
started multiple times.

**state**
Output the state of a container.

**pause**
Pause all the processes in the container.

**resume**
Resume the processes in the container.

**update**
Update container resource constraints.

# STATE

By default, when running as root user, crun saves its state under the
**/run/crun** directory.  As unprivileged user, instead the
*XDG_RUNTIME_DIR* environment variable is honored, and the directory
**$XDG_RUNTIME_DIR/crun** is used.  The global option **--root**
overrides this setting.

# GLOBAL OPTIONS

**--debug**
Produce verbose output.

**--log**=**LOG-DESTINATION**
Define the destination for the error and warning messages generated by
crun.
If the error happens late in the container init process, when crun
already stopped watching it, then it will be printed to the container
stderr.

It is specified in the form *BACKEND:SPECIFIER*.

These following backends are supported:

- file:PATH
- journald:IDENTIFIER
- syslog:IDENTIFIER

If no backend is specified, then *file:* is used by default.

**--log-format**=**FORMAT**
Define the format of the log messages.  It can either be **text**, or
**json**.  The default is **text**.

**--root**=**DIR**
Defines where to store the state for crun containers.

**--systemd-cgroup**
Use systemd for configuring cgroups.  If not specified, the cgroup is
created directly using the cgroupfs backend.

**-?**, **--help**
Print a help list.

**--usage**
Print a short usage message.

**-V**, **--version**
Print program version

## CREATE OPTIONS

crun [global options] create [options] CONTAINER

**--bundle**=**BUNDLE**
Path to the OCI bundle, by default it is the current directory.

**--console-socket**=**SOCKET**
Path to a UNIX socket that will receive the master end of the tty for
the container.

**--no-new-keyring**
Keep the same session key

**--preserve-fds**=**N**
Additional number of FDs to pass into the container.

**--pid-file**=**PATH**
Path to the file that will contain the container process PID.

## RUN OPTIONS

crun [global options] run [options] CONTAINER

**--bundle**=**BUNDLE**
Path to the OCI bundle, by default it is the current directory.

**--console-socket**=**SOCKET**
Path to a UNIX socket that will receive the master end of the tty for
the container.

**--no-new-keyring**
Keep the same session key.

**--preserve-fds**=**N**
Additional number of FDs to pass into the container.

**--pid-file**=**PATH**
Path to the file that will contain the container process PID.

**--detach**
Detach the container process from the current session.

## DELETE OPTIONS

crun [global options] delete [options] CONTAINER

**--force**
Delete the container even if it is still running.

**--regex**=**REGEX**
Delete all the containers that satisfy the specified regex.

## EXEC OPTIONS

crun [global options] exec [options] CONTAINER CMD

**--console-socket**=**SOCKET**
Path to a UNIX socket that will receive the master end of the tty for
the container.

**--cwd**=**PATH**
Set the working directory for the process to PATH.

**--cap**=**CAP**
Specify an additional capability to add to the process.

**--detach**
Detach the container process from the current session.

**--env**=**ENV**
Specify an environment variable.

**--process**=**FILE**
Path to a file containing the process JSON configuration.

**--pid-file**=**PATH**
Path to the file that will contain the new process PID.

**-t** **--tty**
Allocate a pseudo TTY.

**-u USERSPEC** **--user**=**USERSPEC**
Specify the user in the form UID[:GID].

## LIST OPTIONS

crun [global options] list [options]

**-q** **--quiet**
Show only the container ID.

## KILL OPTIONS

crun [global options] kill [options] CONTAINER SIGNAL

**--all**
Kill all the processes in the container.  Currently ignored.

**--regex**=**REGEX**
Kill all the containers that satisfy the specified regex.

## SPEC OPTIONS

crun [global options] spec [options]

**--rootless**
Generate a config.json file that is usable by an unprivileged user.

## UPDATE OPTIONS

crun [global options] update [options] CONTAINER

**--blkio-weight**=**VALUE**
Specifies per cgroup weight.

**--cpu-period**=**VALUE**
CPU CFS period to be used for hardcapping.

--cpu-quota**=**VALUE**
CPU CFS hardcap limit.

**--cpu-rt-period**=**VALUE**
CPU realtime period to be used for hardcapping.

**--cpu-rt-runtime**=**VALUE**
CPU realtime hardcap limit.

**--cpu-share**=**VALUE**
CPU shares.

**--cpuset-cpus**=**VALUE**
CPU(s) to use.

**--cpuset-mems**=**VALUE**
Memory node(s) to use.

**--kernel-memory**=**VALUE**
Kernel memory limit.

**--kernel-memory-tcp**=**VALUE**
Kernel memory limit for TCP buffer.

**--memory**=**VALUE**
Memory limit.

**--memory-reservation**=**VALUE**
Memory reservation or soft_limit.

**--memory-swap**=**VALUE**
Total memory usage.

**--pids-limit**=**VALUE**
Maximum number of pids allowed in the container.

**-r**, **--resources**=**FILE**
Path to the file containing the resources to update.
